@@ -23,7 +23,7 @@ class AltinnAuthClient:
         self.keycloak_secret_path = config.keycloak_secret_path
         self.secret_client = SecretManagerClient()
         self.keycloak_client = KeycloakClient(config.platform_environment)
-        self.guardian_client = GuardianClient(config.platform_environment)
+        self.guardian_client = GuardianClient()
         self.altinn_client = AltinnClient(config.altinn_base_url)
         self.maskinport_client_id = config.maskinport_client_id
 
