@@ -7,8 +7,8 @@ from ssb_altinn3_util.clients.decorators.simple_exception_wrapper import (
 
 
 class GuardianClient:
-    def __init__(self, platform_environment: str):
-        self.token_endpoint = f"https://maskinporten-guardian.{platform_environment}-bip-app.ssb.no/maskinporten/access-token"
+    def __init__(self):
+        self.token_endpoint = f"http://maskinporten-guardian.dapla.svc.cluster.local/maskinporten/access-token"
 
     @exception_handler("Guardian Client")
     def get_token(self, keycloak_token: str) -> str:
