@@ -1,8 +1,12 @@
+import logging
 from threading import Thread
 from typing import Callable
 
 from google.cloud import pubsub_v1
 from google.cloud.pubsub_v1.subscriber.message import Message
+import logging.config
+
+logger = logging.getLogger()
 
 
 class SubscriberThread(Thread):
@@ -26,7 +30,7 @@ class SubscriberThread(Thread):
 
     def run(self) -> None:
         """Creates streaming connection to given PubSub subscription"""
-        print("Creating subscriber")
+        logger.info("Creating subscriber")
         subscriber = pubsub_v1.SubscriberClient()
         subscription_path = subscriber.subscription_path(
             self.project_id, self.subscription_id
@@ -43,7 +47,7 @@ class SubscriberThread(Thread):
             try:
                 streaming_pull_future.result()
             except Exception as e:
-                print(
+                logger.error(
                     f"Listening for messages on {subscription_path} threw an exception: {e}."
                 )
                 # Kills the thread
