@@ -1,9 +1,6 @@
-from pg8000.dbapi import Connection
 from sqlalchemy import create_engine
-from sqlalchemy.engine import Engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker, Session
-from google.cloud.sql.connector import connector
 
 
 class AltinnMottakDbAdapter:
@@ -29,11 +26,16 @@ class AltinnMottakDbAdapter:
         user_password: str,
         project_id: str,
         spanner_instance_id: str,
+        in_memory: bool = False,
     ):
         if spanner_instance_id:
             self.engine = create_engine(
                 f"spanner+spanner:///projects/{project_id}/instances/{spanner_instance_id}/databases/{database_name}"
             )
+        elif in_memory:
+            self.engine = create_engine(
+                "sqlite+pysqlite:///:memory:", echo=True, future=True
+            )
         else:
             self.engine = create_engine(
                 f"postgresql+pg8000://{user_name}:{user_password}@localhost:5432/{database_name}"
